import setuptools
import sys
import os
from shutil import copyfile
from .manager import Manager
from .utils.constants import PACKAGE_FILE, CUR_DIR
from .utils.packages import get_pip_requirements

def build(manager: Manager):
    sys.argv = [sys.argv[0], 'sdist', 'bdist_wheel']

    temp_file = f'{CUR_DIR}/{manager.name}/.ezdeps.json'
    copyfile(PACKAGE_FILE, temp_file)

    print(manager.scripts)

    setuptools.setup(
        name=manager.name,
        version=manager.version,
        author='name' in manager.author and manager.author['name'],
        author_email='email' in manager.author and manager.author['email'],
        description=manager.description,
        scripts=manager.scripts,
        long_description=manager.get_documentation(),
        long_description_content_type='text/markdown',
        packages=setuptools.find_packages(),
        install_requires=get_pip_requirements(manager.get_requirements('default')),
        include_package_data=manager.include_package_data,
        classifiers=manager.classifiers,
        python_requires=manager.python_requires
    )

    os.remove(temp_file)



import sys
import re

def get_setup_params():
    """
    Returns setup params
    """

    if len(sys.argv) == 1:
        # There is no setup params
        return None
    
    directive: str = None
    directive_parmas = []
    params = {}

    param_name = None
    regexp = re.compile(r'-([a-zA-Z])$|--([a-zA-Z]*)$')

    for arg in sys.argv[1:]:
        match = regexp.search(arg)

        if match:
            param_name = match[1] or match[2]
            params[param_name] = True
        elif param_name:
            if params[param_name] == True:
                params[param_name] = []

            params[param_name].append(arg)
        else:
            if directive:
                if params:
                    raise Exception(f'Unexpected directive `{arg}`')
                else:
                    directive_parmas.append(arg)
            else:
                directive = arg

    return {
        'directive': directive,
        'directive_params': directive_parmas,
        'params': params,
    }
